watch<T extends Listenable> method

T watch<T extends Listenable>()

Retrieves the Listenable object of type T from the nearest InheritedProvider ancestor widget and rebuilds the widget tree when it changes.

This method is equivalent to calling of with listen set to true.

Implementation

T watch<T extends Listenable>() => InheritedProvider.of<T>(
      this,
      listen: true,
    );