utils/typedefs library

Typedefs

Provider = InheritedProvider<Listenable>
A type alias for the InheritedProvider class.
ProviderBuilder<R> = Widget Function(BuildContext context, R value)
The type signature for a builder function that takes in a BuildContext and a value of type R, and returns a widget tree that depends on the R value.