buildWithController method
Builds the widget tree that depends on the T object.
This method is called whenever a change occurs in the T object.
Implementation
@override
Widget buildWithController(BuildContext context, T controller) {
return builder(context, controller);
}