builder property
The builder function that returns the widget tree that depends on the
T object.
Implementation
final ProviderBuilder<T> builder;
The builder function that returns the widget tree that depends on the
T object.
final ProviderBuilder<T> builder;