buildWithController abstract method

Widget buildWithController(
  1. BuildContext context,
  2. T controller
)

Builds the widget tree that depends on the T object.

This method is called whenever a change occurs in the T object.

Implementation

Widget buildWithController(BuildContext context, T controller);