ChangeNotifierProvider<T extends ChangeNotifier> class

A widget that creates a ChangeNotifier and provides it to its descendants.

This widget is used to create a ChangeNotifier object of type T and provide it to its descendants via a ListenableProvider widget. It takes in a create function that creates the ChangeNotifier, a builder function that builds the widget tree that depends on the ChangeNotifier, and an optional onDispose function that is called when the widget is disposed.

Inheritance

Constructors

ChangeNotifierProvider({Key? key, required T create(BuildContext context), required ProviderBuilder<T> builder, dynamic onDispose(T controller)?})
const

Properties

builder ProviderBuilder<T>
The builder function that builds the widget tree that depends on the ChangeNotifier.
final
create → T Function(BuildContext context)
The function that creates the ChangeNotifier.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDispose → dynamic Function(T controller)?
An optional function that is called when the widget is disposed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited