builder property
The builder function that builds the widget tree that depends on the ChangeNotifier.
Implementation
final ProviderBuilder<T> builder;
The builder function that builds the widget tree that depends on the ChangeNotifier.
final ProviderBuilder<T> builder;