onDispose property
dynamic Function(T controller)?
onDispose
final
An optional function that is called when the widget is disposed.
Implementation
final Function(T controller)? onDispose;
An optional function that is called when the widget is disposed.
final Function(T controller)? onDispose;