ProviderBuilder<R> typedef
ProviderBuilder<R> =
Widget Function(BuildContext context, R value)
The type signature for a builder function that takes in a BuildContext and
a value of type R, and returns a widget tree that depends on the R value.
This type is commonly used as a parameter for widgets like Provider, which allow you to provide a value to their descendants and rebuild them whenever that value changes.
Implementation
typedef ProviderBuilder<R> = Widget Function(
BuildContext context,
R value,
);