buildWithController abstract method
Builds the widget tree that depends on the T object.
This method is called whenever a change occurs in the T object.
Implementation
Widget buildWithController(BuildContext context, T controller);
Builds the widget tree that depends on the T object.
This method is called whenever a change occurs in the T object.
Widget buildWithController(BuildContext context, T controller);